"""
labbook.py

After modifying this file don't forget to modify __init__.py to expose your package's API.
"""


def a_function_of_mine():
    """
    This function returns the string 'result'.
    """
    return 'result'


class MyClass:
    """
    This is a class that should be documented.
    """
    def a_method_of_mine(self):
        """
        Please document public methods as well.
        """
        return 'another result'

